# brick_game

An old brick game that I used to played as a child re-made using Pygame.

## What is it?

It is sort of run-and-dodge game where you dodge incoming enemy.

## How to install

Simply,

`pip install brick_game`

or download the wheel from the repo.

## Screenshots

![img.png](src/imgs/gameplay.png)
